@@ -1,25 +1,10 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Code to generate and interact with compiled function objects.
 
 """
 
-
 from nuitka.PythonVersions import python_version
 from nuitka.Tracing import general
 
@@ -30,6 +15,7 @@ from .CodeHelpers import (
     generateStatementSequenceCode,
     withObjectCodeTemporaryAssignment,
 )
+from .CodeObjectCodes import getCodeObjectAccessCode
 from .Contexts import PythonFunctionOutlineContext
 from .Emission import SourceCodeCollector
 from .ErrorCodes import getErrorExitCode, getMustNotGetHereCode, getReleaseCode
@@ -58,7 +44,7 @@ from .VariableCodes import (
 def getFunctionCreationArgs(
     defaults_name, kw_defaults_name, annotations_name, closure_variables
 ):
-    result = []
+    result = ["PyThreadState *tstate"]
 
     if defaults_name is not None:
         result.append("PyObject *defaults")
@@ -82,7 +68,6 @@ def getFunctionMakerDecl(
     kw_defaults_name,
     annotations_name,
 ):
-
     function_creation_args = getFunctionCreationArgs(
         defaults_name=defaults_name,
         kw_defaults_name=kw_defaults_name,
@@ -184,10 +169,6 @@ def getFunctionMakerCode(
         function_identifier=function_identifier
     )
 
-    code_identifier = context.getCodeObjectHandle(
-        code_object=function_body.getCodeObject()
-    )
-
     module_identifier = getModuleAccessCode(context=context)
 
     result = template_maker_function_body % {
@@ -198,7 +179,9 @@ def getFunctionMakerCode(
         "function_maker_identifier": function_maker_identifier,
         "function_impl_identifier": function_impl_identifier,
         "function_creation_args": ", ".join(function_creation_args),
-        "code_identifier": code_identifier,
+        "code_identifier": getCodeObjectAccessCode(
+            code_object=function_body.getCodeObject(), context=context
+        ),
         "function_doc": function_doc,
         "defaults": "defaults" if defaults_name else "NULL",
         "kw_defaults": "kw_defaults" if kw_defaults_name else "NULL",
@@ -209,8 +192,10 @@ def getFunctionMakerCode(
         "constant_return_code": indented(constant_return_code),
     }
 
-    # TODO: Make it optional.
-    context.addFunctionCreationInfo(function_impl_identifier)
+    # TODO: Make it optional, only dill plugin really uses that table to
+    # transport the C code implementation pointers.
+    if function_impl_identifier != "NULL":
+        context.addFunctionCreationInfo(function_impl_identifier)
 
     return result
 
@@ -357,7 +342,7 @@ def getFunctionCreationCode(
     emit,
     context,
 ):
-    args = []
+    args = ["tstate"]
 
     if defaults_name is not None:
         getReferenceExportCode(defaults_name, emit, context)
@@ -444,7 +429,7 @@ def getDirectFunctionCallCode(
             """
 {
     PyObject *dir_call_args[] = {%s};
-    %s = %s(dir_call_args%s%s);
+    %s = %s(tstate, dir_call_args%s%s);
 }"""
             % (
                 ", ".join(str(arg_name) for arg_name in arg_names),
@@ -456,7 +441,7 @@ def getDirectFunctionCallCode(
         )
     else:
         emit(
-            "%s = %s(NULL%s%s);"
+            "%s = %s(tstate, NULL%s%s);"
             % (
                 to_name,
                 function_identifier,
@@ -505,7 +490,6 @@ def getFunctionDirectDecl(function_identifier, closure_variables, file_scope, co
 def setupFunctionLocalVariables(
     context, parameters, closure_variables, user_variables, temp_variables
 ):
-
     # Parameter variable initializations
     if parameters is not None:
         for count, variable in enumerate(parameters.getAllVariables()):
@@ -633,7 +617,6 @@ def _getFunctionCode(
     file_scope,
     needs_exception_exit,
 ):
-
     # Functions have many details, that we express as variables, with many
     # branches to decide, pylint: disable=too-many-locals
 
@@ -673,17 +656,13 @@ def _getFunctionCode(
 
     if needs_exception_exit:
         (
-            exception_type,
-            exception_value,
-            exception_tb,
+            exception_state_name,
             _exception_lineno,
         ) = context.variable_storage.getExceptionVariableDescriptions()
 
         function_exit += template_function_exception_exit % {
             "function_cleanup": indented(function_cleanup),
-            "exception_type": exception_type,
-            "exception_value": exception_value,
-            "exception_tb": exception_tb,
+            "exception_state_name": exception_state_name,
         }
 
     if context.hasTempName("return_value"):
@@ -749,7 +728,7 @@ def generateFunctionCallCode(to_name, expression, emit, context):
 
     arg_names = []
     for count, arg_value in enumerate(argument_values, 1):
-        arg_name = context.allocateTempName("dircall_arg%d" % count)
+        arg_name = context.allocateTempName("direct_call_arg%d" % count)
 
         generateExpressionCode(
             to_name=arg_name, expression=arg_value, emit=emit, context=context
@@ -762,7 +741,6 @@ def generateFunctionCallCode(to_name, expression, emit, context):
     with withObjectCodeTemporaryAssignment(
         to_name, "call_result", expression, emit, context
     ) as value_name:
-
         getDirectFunctionCallCode(
             to_name=value_name,
             function_identifier=function_identifier,
@@ -791,7 +769,7 @@ def generateFunctionOutlineCode(to_name, expression, emit, context):
             )
 
             if variable_declaration.getCType() is CTypeCellObject:
-                emit("%s = Nuitka_Cell_Empty();" % variable_declaration)
+                emit("%s = Nuitka_Cell_NewEmpty();" % variable_declaration)
 
     # Need to set return target, to assign to_name from.
 
@@ -852,7 +830,9 @@ def generateFunctionOutlineCode(to_name, expression, emit, context):
 def generateFunctionErrorStrCode(to_name, expression, emit, context):
     generateCAPIObjectCode(
         to_name=to_name,
+        # TODO: Should be inline this for
         capi="_PyObject_FunctionStr",
+        tstate=False,
         arg_desc=(("func_arg", expression.subnode_value),),
         may_raise=False,
         conversion_check=decideConversionCheckNeeded(to_name, expression),
@@ -860,3 +840,19 @@ def generateFunctionErrorStrCode(to_name, expression, emit, context):
         emit=emit,
         context=context,
     )
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
