@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Access to standard library distinction.
 
 For code to be in the standard library means that it's not written by the
@@ -29,9 +15,14 @@ module.
 import os
 
 from nuitka.PythonVersions import python_version
-from nuitka.utils.FileOperations import getFileContents, isFilenameBelowPath
+from nuitka.utils.FileOperations import (
+    getFileContents,
+    getNormalizedPath,
+    isFilenameBelowPath,
+)
 from nuitka.utils.ModuleNames import ModuleName
 from nuitka.utils.Utils import (
+    isMacOS,
     isNetBSD,
     isPosixWindows,
     isWin32OrPosixWindows,
@@ -146,7 +137,7 @@ _is_standard_library_path_cache = {}
 def isStandardLibraryPath(filename):
     """Check if a path is in the standard library."""
 
-    filename = os.path.normcase(os.path.normpath(filename))
+    filename = os.path.normcase(getNormalizedPath(filename))
 
     if filename not in _is_standard_library_path_cache:
         _is_standard_library_path_cache[filename] = _isStandardLibraryPath(filename)
@@ -154,50 +145,55 @@ def isStandardLibraryPath(filename):
     return _is_standard_library_path_cache[filename]
 
 
-# Some modules we want to exclude entirely.
-_excluded_stdlib_modules = ["__main__.py", "__init__.py", "antigravity.py"]
-
-if not isWin32Windows():
-    # On posix systems, and posix Python variants on Windows, this won't
-    # work.
-    _excluded_stdlib_modules.append("wintypes.py")
-    _excluded_stdlib_modules.append("cp65001.py")
-
-
 def scanStandardLibraryPath(stdlib_dir):
     # There is a lot of filtering here, done in branches, so there is many of
-    # them, but that's acceptable, pylint: disable=too-many-branches,too-many-statements
+    # them, but that's acceptable, pylint: disable=too-many-branches
 
     for root, dirs, filenames in os.walk(stdlib_dir):
         import_path = root[len(stdlib_dir) :].strip("/\\")
         import_path = import_path.replace("\\", ".").replace("/", ".")
 
+        def _removeFilenamesIfPresent(*remove_filenames):
+            # pylint: intended for loop usage, pylint: disable=cell-var-from-loop
+            for remove_filename in remove_filenames:
+                if remove_filename in filenames:
+                    filenames.remove(remove_filename)
+
+        def _removeDirsIfPresent(*remove_dirs):
+            # pylint: intended for loop usage, pylint: disable=cell-var-from-loop
+            for remove_dir in remove_dirs:
+                if remove_dir in dirs:
+                    dirs.remove(remove_dir)
+
+        _removeDirsIfPresent("__pycache__")
+
+        # Ignore ".idea", ".git" and similar folders, they are not modules
+        dirs[:] = [dirname for dirname in dirs if not dirname.startswith(".")]
+
         if import_path == "":
-            if "site-packages" in dirs:
-                dirs.remove("site-packages")
-            if "dist-packages" in dirs:
-                dirs.remove("dist-packages")
-            if "vendor-packages" in dirs:
-                dirs.remove("vendor-packages")
-            if "test" in dirs:
-                dirs.remove("test")
-            if "turtledemo" in dirs:
-                dirs.remove("turtledemo")
-
-            if "ensurepip" in filenames:
-                filenames.remove("ensurepip")
-            if "ensurepip" in dirs:
-                dirs.remove("ensurepip")
-
-            # Ignore "lib-dynload" and "lib-tk" and alike.
+            # Ignore "lib-dynload" and "lib-tk" and alike, spell-checker: ignore dynload
             dirs[:] = [
                 dirname
                 for dirname in dirs
                 if not dirname.startswith("lib-")
-                if dirname != "Tools"
                 if not dirname.startswith("plat-")
             ]
 
+            _removeDirsIfPresent(
+                "site-packages",
+                "dist-packages",
+                "vendor-packages",
+                "test",
+                "ensurepip",
+                "turtledemo",
+                "Tools",
+            )
+            _removeFilenamesIfPresent("ensurepip")
+
+            if not isMacOS():
+                _removeFilenamesIfPresent("_ios_support.py")
+
+        # Ignore tests from selected packages, spell-checker: ignore bsddb
         if import_path in (
             "tkinter",
             "Tkinter",
@@ -209,38 +205,40 @@ def scanStandardLibraryPath(stdlib_dir):
             "email",
             "bsddb",
         ):
-            if "test" in dirs:
-                dirs.remove("test")
+            _removeDirsIfPresent("test")
+
+        if import_path in ("lib2to3", "json", "distutils"):
+            _removeDirsIfPresent("tests")
 
         if import_path == "distutils.command":
             # Misbehaving and crashing while importing the world.
-            if "bdist_conda.py" in filenames:
-                filenames.remove("bdist_conda.py")
-
-        if import_path in ("lib2to3", "json", "distutils"):
-            if "tests" in dirs:
-                dirs.remove("tests")
+            _removeFilenamesIfPresent("bdist_conda.py")
 
         if import_path == "asyncio":
-            if "test_utils.py" in filenames:
-                filenames.remove("test_utils.py")
-
-        if python_version >= 0x340 and isWin32Windows():
-            if import_path == "multiprocessing":
-                filenames.remove("popen_fork.py")
-                filenames.remove("popen_forkserver.py")
-                filenames.remove("popen_spawn_posix.py")
+            _removeFilenamesIfPresent("test_utils.py")
 
         if python_version >= 0x300 and isPosixWindows():
+            if import_path == "multiprocessing":
+                _removeFilenamesIfPresent(
+                    "popen_fork.py", "popen_forkserver.py", "popen_spawn_posix.py"
+                )
+
             if import_path == "curses":
-                filenames.remove("has_key.py")
+                _removeFilenamesIfPresent("has_key.py")
 
         if isNetBSD():
             if import_path == "xml.sax":
-                filenames.remove("expatreader.py")
+                _removeFilenamesIfPresent("expatreader.py")
+
+        _removeFilenamesIfPresent("__main__.py", "__init__.py", "antigravity.py")
+
+        if not isWin32Windows():
+            # On POSIX systems, and on POSIX Python variants on Windows, this
+            # won't work.
+            _removeFilenamesIfPresent("wintypes.py", "cp65001.py")
 
         for filename in filenames:
-            if filename.endswith(".py") and filename not in _excluded_stdlib_modules:
+            if filename.endswith(".py"):
                 module_name = filename[:-3]
 
                 if import_path == "":
@@ -248,13 +246,6 @@ def scanStandardLibraryPath(stdlib_dir):
                 else:
                     yield ModuleName(import_path + "." + module_name)
 
-        if python_version >= 0x300:
-            if "__pycache__" in dirs:
-                dirs.remove("__pycache__")
-
-        # Ignore ".idea", ".git" and similar folders, they are not modules
-        dirs = [dirname for dirname in dirs if not dirname.startswith(".")]
-
         for dirname in dirs:
             if import_path == "":
                 yield ModuleName(dirname)
@@ -265,6 +256,7 @@ def scanStandardLibraryPath(stdlib_dir):
 _stdlib_no_auto_inclusion_list = (
     # Avoid this to be included, implicit usages will be rare, but it triggers
     # the Nuitka plugin "multiprocessing" that is always enabled.
+    # spell-checker: ignore _pydecimal,_posixsubprocess,pyexpat,sitecustomize
     "multiprocessing",
     "_multiprocessing",
     # Implicit usages of these will be rare, but it can have that costly extension module
@@ -379,13 +371,13 @@ _stdlib_no_auto_inclusion_list = (
     "py_compile",
     "msilib",
     "_opcode",
-    # tzdata is not always needed
+    # time zone data is not always needed
     "zoneinfo",
     # tkinter under all its names
     "Tkinter",
     "tkinter",
     "_tkinter",
-    # lib-tk from Python2
+    # lib-tk from Python2, spell-checker: ignore Tkdnd,Tkconstants
     "Tix",
     "FixTk",
     "ScrolledText",
@@ -420,6 +412,26 @@ _stdlib_no_auto_inclusion_list = (
 if not isWin32Windows():
     _stdlib_no_auto_inclusion_list += ("ntpath",)
 
+# This was removed, but can exist in some circumstances still.
+if python_version >= 0x3D0:
+    _stdlib_no_auto_inclusion_list += ("cgi",)
+
 
 def isStandardLibraryNoAutoInclusionModule(module_name):
     return module_name.hasOneOfNamespaces(*_stdlib_no_auto_inclusion_list)
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
