@@ -1,5 +1,44 @@
-#     Copyright 2021, Kay Hayen, mailto:kay.hayen@gmail.com
-#
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
+""" Node children checkers.
+
+The role of checkers is to make sure that node children have specific value
+types only.
+
+"""
+
+
+def checkStatementsSequenceOrNone(value):
+    if value is not None:
+        assert value.kind == "STATEMENTS_SEQUENCE", value
+
+        if not value.subnode_statements:
+            return None
+
+    return value
+
+
+def checkStatementsSequence(value):
+    assert value is not None and value.kind == "STATEMENTS_SEQUENCE", value
+
+    return value
+
+
+def convertNoneConstantToNone(node):
+    if node is None or node.isExpressionConstantNoneRef():
+        return None
+    else:
+        return node
+
+
+def convertEmptyStrConstantToNone(node):
+    if node is None or node.isExpressionConstantStrEmptyRef():
+        return None
+    else:
+        return node
+
+
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
 #
@@ -14,22 +53,3 @@
 #     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
-#
-""" Node children checkers.
-
-The role of checkers is to make sure that node children have specific value
-types only.
-
-"""
-
-
-def checkStatementsSequenceOrNone(value):
-    assert value is None or value.kind == "STATEMENTS_SEQUENCE", value
-
-    return value
-
-
-def checkStatementsSequence(value):
-    assert value is not None and value.kind == "STATEMENTS_SEQUENCE", value
-
-    return value
