@@ -1,20 +1,6 @@
-#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Nodes for comparisons.
 
 """
@@ -23,7 +9,8 @@ from nuitka import PythonOperators
 from nuitka.Errors import NuitkaAssumptionError
 from nuitka.PythonVersions import python_version
 
-from .ExpressionBases import ExpressionChildrenHavingBase
+from .ChildrenHavingMixins import ChildrenHavingLeftRightMixin
+from .ExpressionBases import ExpressionBase
 from .ExpressionShapeMixins import ExpressionBoolShapeExactMixin
 from .NodeMakingHelpers import (
     makeConstantReplacementNode,
@@ -34,14 +21,18 @@ from .shapes.BuiltinTypeShapes import tshape_bool, tshape_exception_class
 from .shapes.StandardShapes import tshape_unknown
 
 
-class ExpressionComparisonBase(ExpressionChildrenHavingBase):
+class ExpressionComparisonBase(ChildrenHavingLeftRightMixin, ExpressionBase):
     named_children = ("left", "right")
 
     def __init__(self, left, right, source_ref):
-        ExpressionChildrenHavingBase.__init__(
-            self, values={"left": left, "right": right}, source_ref=source_ref
+        ChildrenHavingLeftRightMixin.__init__(
+            self,
+            left=left,
+            right=right,
         )
 
+        ExpressionBase.__init__(self, source_ref)
+
     @staticmethod
     def copyTraceStateFrom(source):
         pass
@@ -62,7 +53,7 @@ class ExpressionComparisonBase(ExpressionChildrenHavingBase):
     def getSimulator(self):
         return PythonOperators.all_comparison_functions[self.comparator]
 
-    def _computeCompileTimeConstantComparision(self, trace_collection):
+    def _computeCompileTimeConstantComparison(self, trace_collection):
         left_value = self.subnode_left.getCompileTimeConstant()
         right_value = self.subnode_right.getCompileTimeConstant()
 
@@ -72,7 +63,7 @@ class ExpressionComparisonBase(ExpressionChildrenHavingBase):
             description="Comparison of constant arguments.",
         )
 
-    def makeInverseComparision(self):
+    def makeInverseComparison(self):
         # Making this accessing for tree building phase as well.
         return makeComparisonExpression(
             left=self.subnode_left,
@@ -83,7 +74,7 @@ class ExpressionComparisonBase(ExpressionChildrenHavingBase):
 
     def computeExpressionOperationNot(self, not_node, trace_collection):
         if self.getTypeShape() is tshape_bool:
-            result = self.makeInverseComparision()
+            result = self.makeInverseComparison()
 
             result.copyTraceStateFrom(self)
 
@@ -512,10 +503,11 @@ class ExpressionComparisonExceptionMatchBase(
                     description="Exception matched with constant arguments.",
                 )
 
-        # Any code could be run, note that.
-        trace_collection.onControlFlowEscape(self)
+        if self.mayRaiseExceptionComparison():
+            # Any code could be run, note that.
+            trace_collection.onControlFlowEscape(self)
 
-        trace_collection.onExceptionRaiseExit(BaseException)
+            trace_collection.onExceptionRaiseExit(BaseException)
 
         return self, None, None
 
@@ -533,17 +525,21 @@ class ExpressionComparisonExceptionMatchBase(
             or self.mayRaiseExceptionComparison()
         )
 
-    def mayRaiseExceptionComparison(self):
-        if python_version < 0x300:
+    if python_version < 0x300:
+
+        @staticmethod
+        def mayRaiseExceptionComparison():
             return False
 
-        # TODO: Add shape for exceptions.
-        type_shape = self.subnode_right.getTypeShape()
+    else:
 
-        if type_shape is tshape_exception_class:
-            return False
+        def mayRaiseExceptionComparison(self):
+            type_shape = self.subnode_right.getTypeShape()
 
-        return True
+            if type_shape is tshape_exception_class:
+                return False
+
+            return True
 
 
 class ExpressionComparisonExceptionMatch(ExpressionComparisonExceptionMatchBase):
@@ -673,3 +669,19 @@ def makeComparisonExpression(left, right, comparator, source_ref):
     return _comparator_to_nodeclass[comparator](
         left=left, right=right, source_ref=source_ref
     )
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
