@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Conditional nodes.
 
 These is the conditional expression '(a if b else c)' and the conditional
@@ -39,7 +25,8 @@ from .NodeMakingHelpers import (
     wrapStatementWithSideEffects,
 )
 from .OperatorNodesUnary import ExpressionOperationNot
-from .shapes.BuiltinTypeShapes import tshape_bool, tshape_unknown
+from .shapes.BuiltinTypeShapes import tshape_bool
+from .shapes.StandardShapes import tshape_unknown
 from .StatementBasesGenerated import StatementConditionalBase
 from .StatementNodes import StatementsSequence
 
@@ -54,8 +41,6 @@ class ConditionalValueComputeMixin(object):
             trace_collection
         )
         if replacement is not None:
-            assert replacement.isExpression()
-
             self.replaceChild(condition, replacement)
 
             trace_collection.signalChange(
@@ -668,9 +653,7 @@ branches.""",
             yes_branch = branch_yes_collection.computeBranch(branch=yes_branch)
 
             # If it's aborting, it doesn't contribute to merging.
-            if yes_branch is None:
-                branch_yes_collection = None
-            elif yes_branch.isStatementAborting():
+            if yes_branch is not None and yes_branch.isStatementAborting():
                 branch_yes_collection = None
                 needs_merge = False
         else:
@@ -685,9 +668,7 @@ branches.""",
             no_branch = branch_no_collection.computeBranch(branch=no_branch)
 
             # If it's aborting, it doesn't contribute to merging.
-            if no_branch is None:
-                branch_no_collection = None
-            elif no_branch.isStatementAborting():
+            if no_branch is not None and no_branch.isStatementAborting():
                 branch_no_collection = None
                 needs_merge = False
         else:
@@ -774,7 +755,7 @@ Removed conditional statement without effect.""",
                 new_statement,
                 "new_statements",
                 """\
-Condition for branch statement was predicted to be always %s."""
+Condition for branch statement was predicted to be always '%s'."""
                 % choice,
             )
 
@@ -885,3 +866,19 @@ def makeStatementConditional(condition, yes_branch, no_branch, source_ref):
         no_branch=no_branch,
         source_ref=source_ref,
     )
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
