@@ -89,6 +89,14 @@ class NuitkaPluginAntiBloat(NuitkaYamlPluginBase):
                 noinclude_setuptools_mode,
                 "setuptools",
             )
+            self.handled_modules["xformers.ops._triton.tiled_matmul_kernels"] = (
+                noinclude_setuptools_mode,
+                "setuptools",
+            )
+            self.handled_modules["xformers.ops._triton.matmul_perf_model"] = (
+                noinclude_setuptools_mode,
+                "setuptools",
+            )
             self.handled_modules["Cython"] = (
                 noinclude_setuptools_mode,
                 "setuptools",
@@ -574,17 +582,29 @@ Error, cannot exec module '%s', context code '%s' due to: %s"""
         module_name,
         config_prefix,
         anti_bloat_config,
+        function_qualname,
         function_name,
         body,
     ):
-        replace_code = anti_bloat_config.get(config_prefix + "change_function", {}).get(
-            function_name
-        )
+        # Can be "change_function" or "global_change_function"
+        config_item_name = config_prefix + "change_function"
+
+        # TODO: Ought to always use "function_qualname", but for now we cannot
+        # make the switch easily for "change_function" as it we would have to
+        # correct all their uses.
+        if config_prefix == "":
+            replace_code = anti_bloat_config.get(config_item_name, {}).get(
+                function_name
+            )
+        else:
+            replace_code = anti_bloat_config.get(config_item_name, {}).get(
+                function_qualname
+            )
 
         if replace_code == "un-callable":
             replace_code = """'raise RuntimeError("Must not call %s.%s")'""" % (
                 module_name,
-                function_name,
+                function_qualname,
             )
 
         if replace_code is None:
@@ -594,8 +614,8 @@ Error, cannot exec module '%s', context code '%s' due to: %s"""
             config_module_name=config_module_name,
             module_name=module_name,
             expression=replace_code,
-            config_name="module '%s' config '%schange_function' of '%s'"
-            % (module_name, config_prefix, function_name),
+            config_name="module '%s' config '%s' of '%s'"
+            % (module_name, config_item_name, function_name),
             extra_context=self._getContextCode(
                 module_name=module_name, anti_bloat_config=anti_bloat_config
             ),
@@ -624,7 +644,9 @@ Error, cannot exec module '%s', context code '%s' due to: %s"""
 
         return True
 
-    def onFunctionBodyParsing(self, module_name, function_name, body):
+    def onFunctionBodyParsing(
+        self, module_name, function_qualname, function_name, body
+    ):
         result = False
 
         config_module_name = module_name
@@ -643,6 +665,7 @@ Error, cannot exec module '%s', context code '%s' due to: %s"""
                             module_name=module_name,
                             anti_bloat_config=anti_bloat_config,
                             config_prefix="",
+                            function_qualname=function_qualname,
                             function_name=function_name,
                             body=body,
                         ):
@@ -653,6 +676,7 @@ Error, cannot exec module '%s', context code '%s' due to: %s"""
                         module_name=module_name,
                         anti_bloat_config=anti_bloat_config,
                         config_prefix="global_",
+                        function_qualname=function_qualname,
                         function_name=function_name,
                         body=body,
                     ):
