@@ -1,45 +1,29 @@
-#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Reformulation of call expressions.
 
-Consult the developer manual for information. TODO: Add ability to sync
-source code comments with developer manual sections.
+Consult the Developer Manual for information. TODO: Add ability to sync
+source code comments with Developer Manual sections.
 
 """
 
-from nuitka.nodes.AssignNodes import StatementAssignmentVariable
 from nuitka.nodes.CallNodes import makeExpressionCall
 from nuitka.nodes.ConstantRefNodes import makeConstantRefNode
 from nuitka.nodes.ContainerMakingNodes import (
     makeExpressionMakeTuple,
     makeExpressionMakeTupleOrConstant,
 )
-from nuitka.nodes.DictionaryNodes import (
-    makeExpressionMakeDictOrConstant,
-    makeExpressionPairs,
-)
+from nuitka.nodes.DictionaryNodes import makeExpressionMakeDictOrConstant
 from nuitka.nodes.FunctionNodes import (
-    ExpressionFunctionCall,
-    ExpressionFunctionCreation,
     ExpressionFunctionRef,
+    makeExpressionFunctionCall,
+    makeExpressionFunctionCreation,
 )
+from nuitka.nodes.KeyValuePairNodes import makeExpressionPairs
 from nuitka.nodes.OutlineNodes import ExpressionOutlineBody
 from nuitka.nodes.ReturnNodes import StatementReturn
+from nuitka.nodes.VariableAssignNodes import makeStatementAssignmentVariable
 from nuitka.nodes.VariableRefNodes import ExpressionTempVariableRef
 from nuitka.PythonVersions import python_version
 
@@ -60,9 +44,10 @@ from .ComplexCallHelperFunctions import (
 )
 from .ReformulationDictionaryCreation import buildDictionaryUnpackingArgs
 from .ReformulationSequenceCreation import buildListUnpacking
+from .ReformulationTryFinallyStatements import makeTryFinallyReleaseStatement
 from .TreeHelpers import (
     buildNode,
-    buildNodeList,
+    buildNodeTuple,
     getKind,
     makeStatementsSequenceFromStatements,
 )
@@ -71,7 +56,7 @@ from .TreeHelpers import (
 def buildCallNode(provider, node, source_ref):
     called = buildNode(provider, node.func, source_ref)
 
-    if python_version >= 350:
+    if python_version >= 0x350:
         list_star_arg = None
         dict_star_arg = None
 
@@ -82,18 +67,18 @@ def buildCallNode(provider, node, source_ref):
     # new unpacking code.
     for node_arg in node.args[:-1]:
         if getKind(node_arg) == "Starred":
-            assert python_version >= 350
+            assert python_version >= 0x350
             list_star_arg = buildListUnpacking(provider, node.args, source_ref)
-            positional_args = []
+            positional_args = ()
             break
     else:
         if node.args and getKind(node.args[-1]) == "Starred":
-            assert python_version >= 350
+            assert python_version >= 0x350
 
             list_star_arg = buildNode(provider, node.args[-1].value, source_ref)
-            positional_args = buildNodeList(provider, node.args[:-1], source_ref)
+            positional_args = buildNodeTuple(provider, node.args[:-1], source_ref)
         else:
-            positional_args = buildNodeList(provider, node.args, source_ref)
+            positional_args = buildNodeTuple(provider, node.args, source_ref)
 
     # Only the values of keyword pairs have a real source ref, and those only
     # really matter, so that makes sense.
@@ -102,14 +87,14 @@ def buildCallNode(provider, node, source_ref):
 
     for keyword in node.keywords[:-1]:
         if keyword.arg is None:
-            assert python_version >= 350
+            assert python_version >= 0x350
 
             outline_body = ExpressionOutlineBody(
                 provider=provider, name="dict_unpacking_call", source_ref=source_ref
             )
 
             tmp_called = outline_body.allocateTempVariable(
-                temp_scope=None, name="called"
+                temp_scope=None, name="called", temp_type="object"
             )
 
             helper_args = [
@@ -125,8 +110,8 @@ def buildCallNode(provider, node, source_ref):
                 ),
             ]
 
-            dict_star_arg = ExpressionFunctionCall(
-                function=ExpressionFunctionCreation(
+            dict_star_arg = makeExpressionFunctionCall(
+                function=makeExpressionFunctionCreation(
                     function_ref=ExpressionFunctionRef(
                         function_body=getFunctionCallHelperDictionaryUnpacking(),
                         source_ref=source_ref,
@@ -140,23 +125,28 @@ def buildCallNode(provider, node, source_ref):
                 source_ref=source_ref,
             )
 
-            outline_body.setBody(
+            outline_body.setChildBody(
                 makeStatementsSequenceFromStatements(
-                    StatementAssignmentVariable(
+                    makeStatementAssignmentVariable(
                         variable=tmp_called, source=called, source_ref=source_ref
                     ),
-                    StatementReturn(
-                        expression=_makeCallNode(
-                            called=ExpressionTempVariableRef(
-                                variable=tmp_called, source_ref=source_ref
+                    makeTryFinallyReleaseStatement(
+                        provider=outline_body,
+                        tried=StatementReturn(
+                            expression=_makeCallNode(
+                                called=ExpressionTempVariableRef(
+                                    variable=tmp_called, source_ref=source_ref
+                                ),
+                                positional_args=positional_args,
+                                keys=keys,
+                                values=values,
+                                list_star_arg=list_star_arg,
+                                dict_star_arg=dict_star_arg,
+                                source_ref=source_ref,
                             ),
-                            positional_args=positional_args,
-                            keys=keys,
-                            values=values,
-                            list_star_arg=list_star_arg,
-                            dict_star_arg=dict_star_arg,
                             source_ref=source_ref,
                         ),
+                        variables=(tmp_called,),
                         source_ref=source_ref,
                     ),
                 )
@@ -169,7 +159,7 @@ def buildCallNode(provider, node, source_ref):
     # new unpacking code.
 
     if node.keywords and node.keywords[-1].arg is None:
-        assert python_version >= 350
+        assert python_version >= 0x350
 
         dict_star_arg = buildNode(provider, node.keywords[-1].value, source_ref)
         keywords = node.keywords[:-1]
@@ -184,7 +174,7 @@ def buildCallNode(provider, node, source_ref):
         )
         values.append(buildNode(provider, keyword.value, source_ref))
 
-    if python_version < 350:
+    if python_version < 0x350:
         list_star_arg = buildNode(provider, node.starargs, source_ref, True)
         dict_star_arg = buildNode(provider, node.kwargs, source_ref, True)
 
@@ -221,7 +211,7 @@ def _makeCallNode(
         )
 
         # Bug compatible line numbers before Python 3.8
-        if python_version < 380:
+        if python_version < 0x380:
             if values:
                 result.setCompatibleSourceReference(
                     source_ref=values[-1].getCompatibleSourceReference()
@@ -234,7 +224,7 @@ def _makeCallNode(
         return result
     else:
         # Dispatch to complex helper function for each case. These do
-        # re-formulation of complex calls according to developer manual.
+        # re-formulation of complex calls according to Developer Manual.
 
         key = (
             bool(positional_args),
@@ -272,7 +262,7 @@ def _makeCallNode(
             )
 
         # Order of evaluation changed in Python3.5.
-        if python_version >= 350 and list_star_arg is not None:
+        if python_version >= 0x350 and list_star_arg is not None:
             helper_args.append(list_star_arg)
 
         if keys:
@@ -285,14 +275,14 @@ def _makeCallNode(
             )
 
         # Order of evaluation changed in Python3.5.
-        if python_version < 350 and list_star_arg is not None:
+        if python_version < 0x350 and list_star_arg is not None:
             helper_args.append(list_star_arg)
 
         if dict_star_arg is not None:
             helper_args.append(dict_star_arg)
 
-        result = ExpressionFunctionCall(
-            function=ExpressionFunctionCreation(
+        result = makeExpressionFunctionCall(
+            function=makeExpressionFunctionCreation(
                 function_ref=ExpressionFunctionRef(
                     function_body=get_helper(), source_ref=source_ref
                 ),
@@ -306,9 +296,25 @@ def _makeCallNode(
         )
 
         # Bug compatible line numbers before Python 3.8
-        if python_version < 380:
+        if python_version < 0x380:
             result.setCompatibleSourceReference(
                 source_ref=helper_args[-1].getCompatibleSourceReference()
             )
 
         return result
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
