@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Variable closure taking.
 
 This is the completion of variable object completion. The variables were not
@@ -42,7 +28,6 @@ from nuitka.nodes.VariableRefNodes import (
     ExpressionTempVariableRef,
     makeExpressionVariableRef,
 )
-from nuitka.nodes.VariableReleaseNodes import makeStatementReleaseVariable
 from nuitka.PythonVersions import (
     getErrorMessageExecWithNestedFunction,
     python_version,
@@ -51,7 +36,7 @@ from nuitka.Variables import isSharedAmongScopes, releaseSharedScopeInformation
 
 from .Operations import VisitorNoopMixin, visitTree
 from .ReformulationFunctionStatements import addFunctionVariableReleases
-from .ReformulationTryFinallyStatements import makeTryFinallyStatement
+from .ReformulationTryFinallyStatements import makeTryFinallyReleaseStatement
 from .SyntaxErrors import raiseSyntaxError
 
 # Note: We do the variable scope assignment, as an extra step from tree
@@ -162,7 +147,7 @@ class VariableClosureLookupVisitorPhase1(VisitorNoopMixin):
                     temp_scope = provider.allocateTempScope("class_inplace")
 
                     tmp_variable = provider.allocateTempVariable(
-                        temp_scope=temp_scope, name="value"
+                        temp_scope=temp_scope, name="value", temp_type="object"
                     )
 
                     statements = mergeStatements(
@@ -172,7 +157,7 @@ class VariableClosureLookupVisitorPhase1(VisitorNoopMixin):
                                 source=node.subnode_source.subnode_left,
                                 source_ref=node.source_ref,
                             ),
-                            makeTryFinallyStatement(
+                            makeTryFinallyReleaseStatement(
                                 provider=provider,
                                 tried=(
                                     makeStatementAssignmentVariable(
@@ -198,9 +183,7 @@ class VariableClosureLookupVisitorPhase1(VisitorNoopMixin):
                                         source_ref=node.source_ref,
                                     ),
                                 ),
-                                final=makeStatementReleaseVariable(
-                                    variable=tmp_variable, source_ref=node.source_ref
-                                ),
+                                variables=(tmp_variable,),
                                 source_ref=node.source_ref,
                             ),
                         )
@@ -308,32 +291,19 @@ class VariableClosureLookupVisitorPhase1(VisitorNoopMixin):
         elif node.isExpressionGeneratorObjectBody():
             if python_version >= 0x300:
                 self._handleNonLocal(node)
-
-            # Only Python3.4 or later allows for generators to have qualname.
-            if python_version >= 0x340:
                 self._handleQualnameSetup(node)
         elif node.isExpressionCoroutineObjectBody():
             self._handleNonLocal(node)
-
             self._handleQualnameSetup(node)
         elif node.isExpressionAsyncgenObjectBody():
             self._handleNonLocal(node)
-
             self._handleQualnameSetup(node)
-        elif node.isExpressionClassBodyP3():
+        elif node.isExpressionClassMappingBody():
             self._handleNonLocal(node)
-
-            # Python3.4 allows for class declarations to be made global, even
-            # after they were declared, so we need to fix this up.
-            if python_version >= 0x340:
-                self._handleQualnameSetup(node)
+            self._handleQualnameSetup(node)
         elif node.isExpressionFunctionBody():
             if python_version >= 0x300:
                 self._handleNonLocal(node)
-
-            # Python 3.4 allows for class declarations to be made global, even
-            # after they were declared, so we need to fix this up.
-            if python_version >= 0x340:
                 self._handleQualnameSetup(node)
         # Check if continue and break are properly in loops. If not, raise a
         # syntax error.
@@ -471,6 +441,16 @@ can not delete variable '%s' referenced in nested scope"""
                     while node != class_var.getOwner():
                         node = node.getParentVariableProvider()
                         node.getLocalsScope().registerClosureVariable(class_var)
+        elif node.isStatementAssignmentVariableGeneric():
+            node.parent.replaceChild(
+                node,
+                makeStatementAssignmentVariable(
+                    source=node.subnode_source,
+                    variable=node.variable,
+                    variable_version=node.variable_version,
+                    source_ref=node.source_ref,
+                ),
+            )
 
 
 def completeVariableClosures(tree):
@@ -485,3 +465,19 @@ def completeVariableClosures(tree):
 
     # Only used to detect syntax errors.
     releaseSharedScopeInformation(tree)
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
