@@ -1,4 +1,4 @@
-#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
 
 
 """ Tools for tracing memory usage at compiled time.
@@ -96,7 +96,7 @@ def getMemoryInfos():
 
 
 def collectMemoryUsageValue(memory_usage_name):
-    assert memory_usage_name not in _memory_infos
+    assert memory_usage_name not in _memory_infos, memory_usage_name
     _memory_infos[memory_usage_name] = getOwnProcessMemoryUsage()
 
     return _memory_infos[memory_usage_name]
