@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Python tests originally created or extracted from other peoples work. The
-#     parts were too small to be protected.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Assignment tests, cover most forms of them. """
 
 # nuitka-project: --nofollow-imports
@@ -90,12 +76,12 @@ def otherFunction():
         except UnboundLocalError:
             print("Variable g is untouched")
 
-    print("Assignments from too large iterable", end=" ")
+    print("Assignments from too large iterable gave", end=" ")
 
     try:
         d, j = 1, 2, 3
     except Exception as e:
-        print("gave", type(e), repr(e))
+        print(type(e), repr(e))
 
         try:
             print(d)
@@ -282,3 +268,18 @@ optimizeableTargets()
 complexDel()
 sliceDel()
 globalErrors()
+
+#     Python tests originally created or extracted from other peoples work. The
+#     parts were too small to be protected.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
